@@ -17,10 +17,6 @@
 #include "clock-marshallers.h"
 #include "set-timezone.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
 
 #if GTK_CHECK_VERSION (3, 0, 0)
 G_DEFINE_TYPE (ClockLocationTile, clock_location_tile, GTK_TYPE_BIN)
@@ -285,18 +281,16 @@ clock_location_tile_fill (ClockLocationTile *this)
         g_signal_connect (priv->box, "leave-notify-event",
                           G_CALLBACK (enter_or_leave_tile), this);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        alignment = gtk_alignment_new (0, 0, 1, 0);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 3, 3, 3, 0);
-#endif
-
-        tile = gtk_hbox_new (FALSE, 6);
 #if GTK_CHECK_VERSION (3, 0, 0)
+        tile = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         gtk_widget_set_margin_top (tile, 3);
         gtk_widget_set_margin_bottom (tile, 3);
         gtk_widget_set_margin_start (tile, 3);
+#else
+        tile = gtk_hbox_new (FALSE, 6);
+        alignment = gtk_alignment_new (0, 0, 1, 0);
+        gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 3, 3, 3, 0);
 #endif
-        head_section = gtk_vbox_new (FALSE, 0);
 
         priv->city_label = gtk_label_new (NULL);
 #if GTK_CHECK_VERSION (3, 0, 0)
@@ -310,8 +304,10 @@ clock_location_tile_fill (ClockLocationTile *this)
 #endif
 
 #if GTK_CHECK_VERSION (3, 0, 0)
+        head_section = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_box_pack_start (GTK_BOX (head_section), priv->city_label, FALSE, FALSE, 0);
 #else
+        head_section = gtk_vbox_new (FALSE, 0);
         align = gtk_alignment_new (0, 0, 0, 0);
         gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 0, 3);
         gtk_container_add (GTK_CONTAINER (align), priv->city_label);
@@ -337,11 +333,13 @@ clock_location_tile_fill (ClockLocationTile *this)
         gtk_container_add (GTK_CONTAINER (align), priv->weather_icon);
 #endif
 
-        box = gtk_hbox_new (FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (head_section), box, FALSE, FALSE, 0);
 #if GTK_CHECK_VERSION (3, 0, 0)
+        box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+        gtk_box_pack_start (GTK_BOX (head_section), box, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), priv->weather_icon, FALSE, FALSE, 0);
 #else
+        box = gtk_hbox_new (FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (head_section), box, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), align, FALSE, FALSE, 0);
 #endif
         gtk_box_pack_start (GTK_BOX (box), priv->time_label, FALSE, FALSE, 0);
