@@ -60,10 +60,17 @@ struct _NaTrayManager
   GtkOrientation orientation;
   gint padding;
   gint icon_size;
+#if GTK_CHECK_VERSION (3, 0, 0)
+  GdkRGBA fg;
+  GdkRGBA error;
+  GdkRGBA warning;
+  GdkRGBA success;
+#else
   GdkColor fg;
   GdkColor error;
   GdkColor warning;
   GdkColor success;
+#endif
 
   GList *messages;
   GHashTable *socket_table;
@@ -105,10 +112,17 @@ void            na_tray_manager_set_padding     (NaTrayManager      *manager,
 void            na_tray_manager_set_icon_size   (NaTrayManager      *manager,
 						 gint                padding);
 void            na_tray_manager_set_colors      (NaTrayManager      *manager,
+#if GTK_CHECK_VERSION (3, 0, 0)
+						 GdkRGBA            *fg,
+						 GdkRGBA            *error,
+						 GdkRGBA            *warning,
+						 GdkRGBA            *success);
+#else
 						 GdkColor           *fg,
 						 GdkColor           *error,
 						 GdkColor           *warning,
 						 GdkColor           *success);
+#endif
 
 
 G_END_DECLS
