@@ -34,11 +34,6 @@
 #define ICON_SPACING 1
 #define MIN_BOX_SIZE 3
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X, Y) gtk_box_new(GTK_ORIENTATION_VERTICAL, Y)
-#define gtk_hbox_new(X, Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL, Y)
-#endif
-
 typedef struct
 {
   NaTrayManager *tray_manager;
