@@ -35,8 +35,6 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <libmate-desktop/mate-aboutdialog.h>
-
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
@@ -75,12 +73,13 @@ static void window_menu_about(GtkAction* action, WindowMenu* window_menu)
 	};
 
 	char copyright[] = \
+		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
 		"Copyright \xc2\xa9 2003 Sun Microsystems, Inc.\n"
 		"Copyright \xc2\xa9 2001 Free Software Foundation, Inc.\n"
 		"Copyright \xc2\xa9 2000 Helix Code, Inc.";
 
-	mate_show_about_dialog(GTK_WINDOW(window_menu->applet),
+	gtk_show_about_dialog(GTK_WINDOW(window_menu->applet),
 		"program-name", _("Window Selector"),
 		"authors", authors,
 		"comments", _("The Window Selector shows a list of all windows in a menu and lets you browse them."),
