@@ -817,9 +817,12 @@ mate_panel_applet_position_menu (GtkMenu   *menu,
 #endif
 	gdk_window_get_origin (gtk_widget_get_window (widget),
 			       &menu_x, &menu_y);
-#if GTK_CHECK_VERSION (3, 0, 0)
+#if GTK_CHECK_VERSION (3, 20, 0)
+	device = gdk_seat_get_pointer (gdk_display_get_default_seat (gtk_widget_get_display (widget)));
+	gdk_window_get_device_position (gtk_widget_get_window (widget), device, &pointer_x, &pointer_y, NULL);
+#elif GTK_CHECK_VERSION (3, 0, 0)
 	device = gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gtk_widget_get_display (widget)));
-	gdk_window_get_device_position(gtk_widget_get_window (widget), device, &pointer_x, &pointer_y, NULL);
+	gdk_window_get_device_position (gtk_widget_get_window (widget), device, &pointer_x, &pointer_y, NULL);
 #else
 	gtk_widget_get_pointer (widget, &pointer_x, &pointer_y);
 #endif
@@ -933,6 +936,23 @@ mate_panel_applet_button_event (GtkWidget      *widget,
 	socket_window = gtk_plug_get_socket_window (GTK_PLUG (widget));
 
 	if (event->type == GDK_BUTTON_PRESS) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+#if GTK_CHECK_VERSION (3, 20, 0)
+		GdkDisplay *display;
+		GdkSeat *seat;
+
+		xevent.xbutton.type = ButtonPress;
+
+		display = gdk_display_get_default ();
+		seat = gdk_display_get_default_seat (display);
+
+		/* X does an automatic pointer grab on button press
+		 * if we have both button press and release events
+		 * selected.
+		 * We don't want to hog the pointer on our parent.
+		 */
+		gdk_seat_ungrab (seat);
+#else
 		xevent.xbutton.type = ButtonPress;
 
 		/* X does an automatic pointer grab on button press
@@ -940,9 +960,16 @@ mate_panel_applet_button_event (GtkWidget      *widget,
 		 * selected.
 		 * We don't want to hog the pointer on our parent.
 		 */
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gdk_device_ungrab (event->device, GDK_CURRENT_TIME);
+#endif
 #else
+		xevent.xbutton.type = ButtonPress;
+
+		/* X does an automatic pointer grab on button press
+		 * if we have both button press and release events
+		 * selected.
+		 * We don't want to hog the pointer on our parent.
+		 */
 		gdk_display_pointer_ungrab
 			(gtk_widget_get_display (widget),
 			 GDK_CURRENT_TIME);
