@@ -33,6 +33,10 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-desktop-utils.h>
+#include <libmate-desktop/mate-gsettings.h>
+
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-launch.h>
 #include <libpanel-util/panel-session-manager.h>
@@ -206,12 +210,14 @@ static void
 panel_action_logout (GtkWidget *widget)
 {
 	PanelSessionManager *manager;
-	gboolean             prompt;
+	gboolean             prompt = TRUE;
 
-	GSettings *msm_settings;
-	msm_settings = g_settings_new (MATE_SESSION_SCHEMA);
-	prompt = g_settings_get_boolean (msm_settings, MATE_SESSION_LOGOUT_PROMPT_KEY);
-	g_object_unref (msm_settings);
+	if (mate_gsettings_schema_exists (MATE_SESSION_SCHEMA)) {
+		GSettings *msm_settings;
+		msm_settings = g_settings_new (MATE_SESSION_SCHEMA);
+		prompt = g_settings_get_boolean (msm_settings, MATE_SESSION_LOGOUT_PROMPT_KEY);
+		g_object_unref (msm_settings);
+	}
 
 	manager = panel_session_manager_get ();
 
@@ -285,13 +291,21 @@ static void
 panel_action_connect_server (GtkWidget *widget)
 {
 	GdkScreen *screen;
+	char      *command;
 	GError    *error;
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (widget));
 	error = NULL;
 
-	gdk_spawn_command_line_on_screen (screen, "caja-connect-server",
-					  &error);
+	if (panel_is_program_in_path ("caja-connect-server"))
+		command = g_strdup ("caja-connect-server");
+	else if (panel_is_program_in_path ("nautilus-connect-server"))
+		command = g_strdup ("nautilus-connect-server");
+	else
+		command = g_strdup ("nemo-connect-server");
+
+	mate_gdk_spawn_command_line_on_screen (screen, command, &error);
+	g_free (command);
 
 	if (error) {
 		panel_error_dialog (NULL, screen,
@@ -680,7 +694,11 @@ panel_action_button_connect_to_gsettings (PanelActionButton *button)
 }
 
 static void
+#if GTK_CHECK_VERSION (3, 0, 0)
+panel_action_button_style_updated (PanelActionButton *button)
+#else
 panel_action_button_style_set (PanelActionButton *button)
+#endif
 {
 	if (actions [button->priv->type].icon_name != NULL)
 		button_widget_set_icon_name (BUTTON_WIDGET (button), actions [button->priv->type].icon_name);
@@ -695,18 +713,16 @@ panel_action_button_load (PanelActionButtonType  type,
 			  const char            *id)
 {
 	PanelActionButton *button;
-	PanelObjectType    object_type;
 
 	g_return_if_fail (panel != NULL);
 
 	button = g_object_new (PANEL_TYPE_ACTION_BUTTON, "action-type", type, NULL);
 
-	object_type = PANEL_OBJECT_ACTION;
 
 	button->priv->info = mate_panel_applet_register (GTK_WIDGET (button),
 						    NULL, NULL,
 						    panel, locked, position,
-						    exactpos, object_type, id);
+						    exactpos, PANEL_OBJECT_ACTION, id);
 	if (!button->priv->info) {
 		gtk_widget_destroy (GTK_WIDGET (button));
 		return;
@@ -726,8 +742,13 @@ panel_action_button_load (PanelActionButtonType  type,
 
 	panel_action_button_connect_to_gsettings (button);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	g_signal_connect (button, "style-updated",
+			  G_CALLBACK (panel_action_button_style_updated), NULL);
+#else
 	g_signal_connect (button, "style-set",
 			  G_CALLBACK (panel_action_button_style_set), NULL);
+#endif
 }
 
 void
@@ -795,7 +816,7 @@ panel_action_button_invoke_menu (PanelActionButton *button,
 
 		screen = gtk_widget_get_screen (GTK_WIDGET (button));
 
-		panel_show_help (screen, "user-guide",
+		panel_show_help (screen, "mate-user-guide",
 				 actions [button->priv->type].help_index, NULL);
 
 		return;
