@@ -488,8 +488,12 @@ mate_panel_applet_frame_button_changed (GtkWidget      *widget,
 	gboolean              handled = FALSE;
 #if GTK_CHECK_VERSION (3, 0, 0)
 	GdkDisplay *display;
+#if GTK_CHECK_VERSION (3, 20, 0)
+	GdkSeat *seat;
+#else
 	GdkDevice *pointer;
 	GdkDeviceManager *device_manager;
+#endif
 #endif
 
 	frame = MATE_PANEL_APPLET_FRAME (widget);
@@ -519,7 +523,11 @@ mate_panel_applet_frame_button_changed (GtkWidget      *widget,
 	case 3:
 		if (event->type == GDK_BUTTON_PRESS ||
 		    event->type == GDK_2BUTTON_PRESS) {
-#if GTK_CHECK_VERSION (3, 0, 0)
+#if GTK_CHECK_VERSION(3, 20, 0)
+			display = gtk_widget_get_display (widget);
+			seat = gdk_display_get_default_seat (display);
+			gdk_seat_ungrab (seat);
+#elif GTK_CHECK_VERSION (3, 0, 0)
 			display = gtk_widget_get_display (widget);
 			device_manager = gdk_display_get_device_manager (display);
 			pointer = gdk_device_manager_get_client_pointer (device_manager);
