@@ -128,8 +128,8 @@ panel_profile_find_new_id (PanelGSettingsKeyType type)
 {
 	gchar      **existing_ids;
 	char        *retval = NULL;
-	char        *prefix;
-	char        *dir;
+	char        *prefix = NULL;
+	char        *dir = NULL;
 	int          i;
 	int          j;
 
@@ -143,7 +143,6 @@ panel_profile_find_new_id (PanelGSettingsKeyType type)
 			dir = PANEL_OBJECT_PATH;
 			break;
 		default:
-			prefix = dir = NULL;
 			g_assert_not_reached ();
 			break;
 	}
@@ -232,57 +231,39 @@ panel_profile_get_background_type (PanelToplevel *toplevel)
 	return background_type;
 }
 
+#if GTK_CHECK_VERSION (3, 0, 0)
 void
 panel_profile_set_background_color (PanelToplevel *toplevel,
-#if GTK_CHECK_VERSION (3, 0, 0)
 				    GdkRGBA       *color)
-#else
-				    PanelColor    *color)
-#endif
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	panel_profile_set_background_gdk_rgba_color (toplevel, color);
-#else
-	panel_profile_set_background_gdk_color (toplevel, &color->gdk);
-	panel_profile_set_background_opacity (toplevel, color->alpha);
-#endif
+	panel_profile_set_background_gdk_rgba (toplevel, color);
 }
 
 void
 panel_profile_get_background_color (PanelToplevel *toplevel,
-#if GTK_CHECK_VERSION (3, 0, 0)
 				    GdkRGBA       *color)
-#else
-				    PanelColor    *color)
-#endif
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	panel_profile_get_background_gdk_rgba_color (toplevel, color);
-#else
-	panel_profile_get_background_gdk_color (toplevel, &(color->gdk));
-	color->alpha = panel_profile_get_background_opacity (toplevel);
-#endif
+	panel_profile_get_background_gdk_rgba (toplevel, color);
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 void
-panel_profile_set_background_gdk_rgba_color (PanelToplevel *toplevel,
+panel_profile_set_background_gdk_rgba (PanelToplevel *toplevel,
 					GdkRGBA      *color)
 {
-	char        *color_str;
+	char *color_str;
 
 	color_str = gdk_rgba_to_string (color);
 
-	g_settings_set_string(toplevel->background_settings, "color", color_str);
+	g_settings_set_string (toplevel->background_settings, "color", color_str);
 
 	g_free (color_str);
 }
 
 void
-panel_profile_get_background_gdk_rgba_color (PanelToplevel *toplevel,
+panel_profile_get_background_gdk_rgba (PanelToplevel *toplevel,
 					GdkRGBA      *color)
 {
-	char        *color_str;
+	char *color_str;
 
 	color_str = g_settings_get_string (toplevel->background_settings, "color");
 	if (!color_str || !gdk_rgba_parse (color, color_str)) {
@@ -294,19 +275,53 @@ panel_profile_get_background_gdk_rgba_color (PanelToplevel *toplevel,
 
 	g_free (color_str);
 }
+
+void
+panel_profile_set_background_opacity (PanelToplevel *toplevel,
+				      guint16        opacity)
+{
+	GdkRGBA color;
+	panel_profile_get_background_color (toplevel, &color);
+	color.alpha = opacity / 65535.0;
+	panel_profile_set_background_color (toplevel, &color);
+}
+
+guint16
+panel_profile_get_background_opacity (PanelToplevel *toplevel)
+{
+	GdkRGBA color;
+	panel_profile_get_background_color (toplevel, &color);
+	return (guint16) round (color.alpha * 65535);
+}
 #else
+void
+panel_profile_set_background_color (PanelToplevel *toplevel,
+				    PanelColor    *color)
+{
+	panel_profile_set_background_gdk_color (toplevel, &color->gdk);
+	panel_profile_set_background_opacity (toplevel, color->alpha);
+}
+
+void
+panel_profile_get_background_color (PanelToplevel *toplevel,
+				    PanelColor    *color)
+{
+	panel_profile_get_background_gdk_color (toplevel, &(color->gdk));
+	color->alpha = panel_profile_get_background_opacity (toplevel);
+}
+
 void
 panel_profile_set_background_gdk_color (PanelToplevel *toplevel,
 					GdkColor      *gdk_color)
 {
-	char        *color_str;
+	char *color_str;
 
 	color_str = g_strdup_printf ("#%02x%02x%02x",
 				     gdk_color->red   / 256,
 				     gdk_color->green / 256,
 				     gdk_color->blue  / 256);
 
-	g_settings_set_string(toplevel->background_settings, "color", color_str);
+	g_settings_set_string (toplevel->background_settings, "color", color_str);
 
 	g_free (color_str);
 }
@@ -315,7 +330,7 @@ void
 panel_profile_get_background_gdk_color (PanelToplevel *toplevel,
 					GdkColor      *gdk_color)
 {
-	char        *color_str;
+	char *color_str;
 
 	color_str = g_settings_get_string (toplevel->background_settings, "color");
 	if (!color_str || !gdk_color_parse (color_str, gdk_color)) {
@@ -326,35 +341,22 @@ panel_profile_get_background_gdk_color (PanelToplevel *toplevel,
 
 	g_free (color_str);
 }
-#endif
 
 void
 panel_profile_set_background_opacity (PanelToplevel *toplevel,
 				      guint16        opacity)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	GdkRGBA color;
-	panel_profile_get_background_color(toplevel,&color);
-	color.alpha=opacity/65535.0;
-	panel_profile_set_background_color(toplevel,&color);
-#else
 	g_settings_set_int (toplevel->background_settings, "opacity", opacity);
-#endif
 }
 
 guint16
 panel_profile_get_background_opacity (PanelToplevel *toplevel)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	GdkRGBA color;
-	panel_profile_get_background_color(toplevel,&color);
-	return (guint16)round(color.alpha*65535);
-#else
-	guint16      opacity;
+	guint16 opacity;
 	opacity = g_settings_get_int (toplevel->background_settings, "opacity");
 	return opacity;
-#endif
 }
+#endif
 
 void
 panel_profile_set_background_image (PanelToplevel *toplevel,
@@ -369,9 +371,7 @@ panel_profile_set_background_image (PanelToplevel *toplevel,
 char *
 panel_profile_get_background_image (PanelToplevel *toplevel)
 {
-	char        *retval;
-	retval = g_settings_get_string (toplevel->background_settings, "image");
-	return retval;
+	return g_settings_get_string (toplevel->background_settings, "image");
 }
 
 void
@@ -387,9 +387,7 @@ panel_profile_set_toplevel_name (PanelToplevel *toplevel,
 char *
 panel_profile_get_toplevel_name (PanelToplevel *toplevel)
 {
-	char        *retval;
-	retval = g_settings_get_string (toplevel->settings, "name");
-	return retval;
+	return g_settings_get_string (toplevel->settings, "name");
 }
 
 void
@@ -402,7 +400,7 @@ panel_profile_set_toplevel_orientation (PanelToplevel    *toplevel,
 PanelOrientation
 panel_profile_get_toplevel_orientation (PanelToplevel *toplevel)
 {
-	PanelOrientation  orientation;
+	PanelOrientation orientation;
 	orientation = g_settings_get_enum (toplevel->settings, "orientation");
 	return orientation;
 }
@@ -556,36 +554,40 @@ panel_profile_is_writable_attached_tooltip (PanelToplevel *toplevel)
 	return is_writable;
 }
 
+#if GTK_CHECK_VERSION (3, 0, 0)
 static void
 get_background_color (PanelToplevel *toplevel,
-#if GTK_CHECK_VERSION (3, 0, 0)
 					  GdkRGBA       *color)
-#else
-					  PanelColor    *color)
-#endif
 {
 	char       *color_str;
 	color_str = g_settings_get_string (toplevel->background_settings, "color");
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (!color_str || !gdk_rgba_parse (color, color_str)) {
 		color->red   = 0;
 		color->green = 0;
 		color->blue  = 0;
 		color->alpha  = 1;
 	}
+
+	g_free (color_str);
+}
 #else
+static void
+get_background_color (PanelToplevel *toplevel,
+					  PanelColor    *color)
+{
+	char       *color_str;
+	color_str = g_settings_get_string (toplevel->background_settings, "color");
 	if (!color_str || !gdk_color_parse (color_str, &(color->gdk))) {
 		color->gdk.red   = 0;
 		color->gdk.green = 0;
 		color->gdk.blue  = 0;
 	}
-#endif
+
 	g_free (color_str);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
 	color->alpha = g_settings_get_int (toplevel->background_settings, "opacity");
-#endif
 }
+#endif
 
 static char *
 get_background_image (PanelToplevel *toplevel,
@@ -593,7 +595,7 @@ get_background_image (PanelToplevel *toplevel,
 		      gboolean     *stretch,
 		      gboolean     *rotate)
 {
-	char       *image;
+	char *image;
 	image = g_settings_get_string (toplevel->background_settings, "image");
 	*fit = g_settings_get_boolean (toplevel->background_settings, "fit");
 	*stretch = g_settings_get_boolean (toplevel->background_settings, "stretch");
@@ -618,8 +620,12 @@ panel_profile_load_background (PanelToplevel *toplevel)
 	gboolean             rotate;
 
 	panel_widget = panel_toplevel_get_panel_widget (toplevel);
-	background = &panel_widget->background;
 
+#if GTK_CHECK_VERSION (3, 18, 0)
+	background = &panel_widget->toplevel->background;
+#else
+	background = &panel_widget->background;
+#endif
 	background_type = panel_profile_get_background_type (toplevel);
 
 	get_background_color (toplevel, &color);
@@ -652,7 +658,7 @@ static void
 panel_profile_queue_toplevel_location_change (PanelToplevel          *toplevel,
 					      ToplevelLocationChange *change)
 {
-	guint           commit_timeout;
+	guint commit_timeout;
 
 	g_settings_delay (toplevel->queued_settings);
 
@@ -899,11 +905,16 @@ panel_profile_background_change_notify (GSettings *settings,
 
 	if (toplevel == NULL || !PANEL_IS_TOPLEVEL (toplevel))
 		return;
+
 	panel_widget = panel_toplevel_get_panel_widget (toplevel);
 	if (panel_widget == NULL)
 		return;
-	background = &panel_widget->background;
 
+#if GTK_CHECK_VERSION (3, 18, 0)
+	background = &panel_widget->toplevel->background;
+#else
+	background = &panel_widget->background;
+#endif
 	if (!strcmp (key, "type")) {
 		PanelBackgroundType  background_type;
 		background_type = g_settings_get_enum (settings, key);
@@ -918,7 +929,7 @@ panel_profile_background_change_notify (GSettings *settings,
 			panel_background_set_color (background, &color);
 		g_free (str);
 #else
-		GdkColor    gdk_color;
+		GdkColor gdk_color;
 		gchar *str;
 		str = g_settings_get_string (settings, key);
 		if (gdk_color_parse (str, &gdk_color))
@@ -944,57 +955,44 @@ panel_profile_background_change_notify (GSettings *settings,
 	}
 }
 
+static const char *
+key_from_type (PanelGSettingsKeyType type) {
+	if (type == PANEL_GSETTINGS_TOPLEVELS)
+		return PANEL_TOPLEVEL_ID_LIST_KEY;
+	else if (type == PANEL_GSETTINGS_OBJECTS)
+		return PANEL_OBJECT_ID_LIST_KEY;
+
+	g_assert_not_reached ();
+	return NULL;
+}
+
 void
 panel_profile_add_to_list (PanelGSettingsKeyType  type,
 						   const char        *id)
 {
-	char  *key = NULL;
-	char  *new_id = NULL;
+	char *new_id = id ? g_strdup (id) : panel_profile_find_new_id (type);
 
-	new_id = id ? g_strdup (id) : panel_profile_find_new_id (type);
-
-	if (type == PANEL_GSETTINGS_TOPLEVELS)
-		key = g_strdup (PANEL_TOPLEVEL_ID_LIST_KEY);
-	else if (type == PANEL_GSETTINGS_OBJECTS)
-		key = g_strdup (PANEL_OBJECT_ID_LIST_KEY);
-
-        if ((key != NULL) && (new_id != NULL)) {
-	        mate_gsettings_append_strv (profile_settings,
-								 key,
-								 new_id);
-	        g_free (key);
-	        g_free (new_id);
-        }
+    if (new_id != NULL) {
+		mate_gsettings_append_strv (profile_settings,
+		                            key_from_type (type),
+		                            new_id);
+		g_free (new_id);
+    }
 }
 
 void
 panel_profile_remove_from_list (PanelGSettingsKeyType  type,
 								const char        *id)
 {
-	gchar *key;
-	if (type == PANEL_GSETTINGS_TOPLEVELS)
-		key = g_strdup (PANEL_TOPLEVEL_ID_LIST_KEY);
-	else if (type == PANEL_GSETTINGS_OBJECTS)
-		key = g_strdup (PANEL_OBJECT_ID_LIST_KEY);
-	
 	mate_gsettings_remove_all_from_strv (profile_settings,
-										  key,
-										  id);
-	g_free (key);
+	                                     key_from_type (type),
+	                                     id);
 }
 
 static gboolean
 panel_profile_id_list_is_writable (PanelGSettingsKeyType type)
 {
-	gboolean is_writable;
-	gchar  *key;
-	if (type == PANEL_GSETTINGS_TOPLEVELS)
-		key = g_strdup (PANEL_TOPLEVEL_ID_LIST_KEY);
-	else if (type == PANEL_GSETTINGS_OBJECTS)
-		key = g_strdup (PANEL_OBJECT_ID_LIST_KEY);
-	is_writable = g_settings_is_writable (profile_settings, key);
-	g_free (key);
-	return is_writable;
+	return g_settings_is_writable (profile_settings, key_from_type (type));
 }
 
 gboolean
@@ -1153,10 +1151,10 @@ panel_profile_delete_toplevel (PanelToplevel *toplevel)
 	panel_profile_remove_from_list (PANEL_GSETTINGS_TOPLEVELS, toplevel_id);
 }
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static GdkScreen *
 get_toplevel_screen (char *toplevel_path)
 {
-
 	GdkDisplay *display;
 	GSettings  *settings;
 	int         screen_n;
@@ -1178,6 +1176,7 @@ get_toplevel_screen (char *toplevel_path)
 
 	return gdk_display_get_screen (display, screen_n);
 }
+#endif
 
 PanelToplevel *
 panel_profile_load_toplevel (const char *toplevel_id)
@@ -1192,7 +1191,13 @@ panel_profile_load_toplevel (const char *toplevel_id)
 
 	toplevel_path = g_strdup_printf ("%s%s/", PANEL_TOPLEVEL_PATH, toplevel_id);
 
-	if (!(screen = get_toplevel_screen (toplevel_path))) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+	screen = gdk_display_get_default_screen (gdk_display_get_default ());
+#else
+	screen = get_toplevel_screen (toplevel_path);
+#endif
+
+	if (screen == NULL) {
 		g_free (toplevel_path);
 		return NULL;
 	}
@@ -1449,6 +1454,9 @@ panel_profile_delete_dir (PanelGSettingsKeyType  type,
 		case PANEL_GSETTINGS_OBJECTS:
 			dir = g_strdup_printf (PANEL_OBJECT_PATH "%s/", id);
 			break;
+		default:
+			g_assert_not_reached ();
+			break;
 	}
 
 	if (type == PANEL_GSETTINGS_TOPLEVELS) {
@@ -1464,10 +1472,10 @@ panel_profile_delete_dir (PanelGSettingsKeyType  type,
 		g_free (subdir);
 	}
 
-        if (dir != NULL) {
-	        mate_dconf_recursive_reset (dir, NULL);
-	        g_free (dir);
-        }
+	if (dir != NULL) {
+		mate_dconf_recursive_reset (dir, NULL);
+		g_free (dir);
+	}
 }
 
 static gboolean
@@ -1586,9 +1594,9 @@ panel_profile_toplevel_id_list_notify (GSettings *settings,
 
 	toplevel_ids_strv = g_settings_get_strv (settings, key);
 
-	toplevel_ids = mate_gsettings_strv_to_gslist (toplevel_ids_strv);
+	toplevel_ids = mate_gsettings_strv_to_gslist ((const gchar **) toplevel_ids_strv);
 	toplevel_ids = panel_g_slist_make_unique (toplevel_ids,
-						  (GCompareFunc)g_strcmp0,
+						  (GCompareFunc) g_strcmp0,
 						  FALSE);
 	g_strfreev (toplevel_ids_strv);
 
@@ -1630,9 +1638,9 @@ panel_profile_object_id_list_update (gchar **objects)
 	GSList *sublist = NULL, *l;
 	GSList *object_ids;
 
-	object_ids = mate_gsettings_strv_to_gslist (objects);
+	object_ids = mate_gsettings_strv_to_gslist ((const gchar **) objects);
 	object_ids = panel_g_slist_make_unique (object_ids,
-						(GCompareFunc)g_strcmp0,
+						(GCompareFunc) g_strcmp0,
 						FALSE);
 
 	existing_applets = mate_panel_applet_list_applets ();
@@ -1678,30 +1686,23 @@ panel_profile_load_list (GSettings              *settings,
 						 GCallback               notify_handler)
 {
 
-	gchar  *key = NULL;
+	const gchar *key = key_from_type (type);
 	gchar  *changed_signal;
 	gchar **list;
 	gint    i;
 
-	if (type == PANEL_GSETTINGS_TOPLEVELS)
-		key = g_strdup (PANEL_TOPLEVEL_ID_LIST_KEY);
-	else if (type == PANEL_GSETTINGS_OBJECTS)
-		key = g_strdup (PANEL_OBJECT_ID_LIST_KEY);
-
-        g_assert (key != NULL);
 	changed_signal = g_strdup_printf ("changed::%s", key);
-
 	g_signal_connect (settings, changed_signal, G_CALLBACK (notify_handler), NULL); 
+	g_free (changed_signal);
 
 	list = g_settings_get_strv (settings, key);
 
 	for (i = 0; list[i]; i++) {
 		load_handler (list[i]);
 	}
+
 	if (list)
 		g_strfreev (list);
-	g_free (changed_signal);
-	g_free (key);
 }
 
 static void
@@ -1711,16 +1712,27 @@ panel_profile_ensure_toplevel_per_screen ()
 	GSList     *empty_screens = NULL;
 	GSList     *l;
 	GdkDisplay *display;
+	GdkScreen  *screen;
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	int         n_screens, i;
+#endif
 
 	toplevels = panel_toplevel_list_toplevels ();
 
 	display = gdk_display_get_default ();
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	screen = gdk_display_get_default_screen (display);
+
+	for (l = toplevels; l; l = l->next)
+		if (gtk_window_get_screen (l->data) == screen)
+			break;
+
+	if (!l)
+		empty_screens = g_slist_prepend (empty_screens, screen);
+#else
 	n_screens = gdk_display_get_n_screens (display);
 	for (i = 0; i < n_screens; i++) {
-		GdkScreen *screen;
-
 		screen = gdk_display_get_screen (display, i);
 
 		for (l = toplevels; l; l = l->next)
@@ -1730,6 +1742,7 @@ panel_profile_ensure_toplevel_per_screen ()
 		if (!l)
 			empty_screens = g_slist_prepend (empty_screens, screen);
 	}
+#endif
 
 	for (l = empty_screens; l; l = l->next)
 		panel_layout_apply_default_from_gkeyfile (l->data);
