@@ -36,7 +36,9 @@
 #include <libpanel-util/panel-icon-chooser.h>
 #include <libpanel-util/panel-show.h>
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 #include <libmate-desktop/mate-colorbutton.h>
+#endif
 
 #include "nothing.h"
 #include "panel-profile.h"
@@ -329,7 +331,11 @@ SETUP_TOGGLE_BUTTON ("arrows_toggle",      arrows_toggle,      enable_arrows,
 
 static void
 panel_properties_dialog_color_changed (PanelPropertiesDialog *dialog,
-				       MateColorButton        *color_button)
+#if GTK_CHECK_VERSION (3, 0, 0)
+				       GtkColorChooser       *color_button)
+#else
+				       MateColorButton       *color_button)
+#endif
 {
 #if GTK_CHECK_VERSION (3, 0, 0)
 	GdkRGBA color;
@@ -340,7 +346,7 @@ panel_properties_dialog_color_changed (PanelPropertiesDialog *dialog,
 	g_assert (dialog->color_button == GTK_WIDGET (color_button));
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-	mate_color_button_get_rgba (color_button, &color);
+	gtk_color_chooser_get_rgba (color_button, &color);
 	panel_profile_set_background_gdk_rgba (dialog->toplevel, &color);
 	panel_properties_dialog_opacity_changed (dialog);
 #else
@@ -367,8 +373,8 @@ panel_properties_dialog_setup_color_button (PanelPropertiesDialog *dialog,
 	panel_profile_get_background_color (dialog->toplevel, &color);
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-	mate_color_button_set_rgba (MATE_COLOR_BUTTON (dialog->color_button),
-				    &color);
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (dialog->color_button),
+				     &color);
 #else
 	mate_color_button_set_color (MATE_COLOR_BUTTON (dialog->color_button),
 				     &(color.gdk));
@@ -723,11 +729,11 @@ panel_properties_dialog_update_background_color (PanelPropertiesDialog *dialog,
 	if (!gdk_rgba_parse (&new_color, str_color))
 		return;
 
-	mate_color_button_get_rgba (MATE_COLOR_BUTTON (dialog->color_button),
+	gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (dialog->color_button),
 				    &old_color);
 
 	if (!gdk_rgba_equal (&old_color, &new_color))
-		mate_color_button_set_rgba (MATE_COLOR_BUTTON (dialog->color_button),
+		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (dialog->color_button),
 					    &new_color);
 #else
 	GdkColor new_color = { 0, };
@@ -813,7 +819,11 @@ static void
 panel_properties_dialog_remove_orientation_combo (PanelPropertiesDialog *dialog)
 {
 	GtkContainer *container = GTK_CONTAINER (dialog->general_table);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	GtkGrid      *grid      = GTK_GRID (dialog->general_table);
+#else
 	GtkTable     *table     = GTK_TABLE (dialog->general_table);
+#endif
 
 	g_object_ref (dialog->size_label);
 	g_object_ref (dialog->size_widgets);
@@ -827,10 +837,17 @@ panel_properties_dialog_remove_orientation_combo (PanelPropertiesDialog *dialog)
 	gtk_container_remove (container, dialog->icon_label);
 	gtk_container_remove (container, dialog->icon_align);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_grid_attach (grid, dialog->size_label,   0, 1, 1, 1);
+	gtk_grid_attach (grid, dialog->size_widgets, 1, 1, 1, 1);
+	gtk_grid_attach (grid, dialog->icon_label,   0, 2, 1, 1);
+	gtk_grid_attach (grid, dialog->icon_align,   1, 2, 1, 1);
+#else
 	gtk_table_attach_defaults (table, dialog->size_label,   0, 1, 1, 2);
 	gtk_table_attach_defaults (table, dialog->size_widgets, 1, 2, 1, 2);
 	gtk_table_attach_defaults (table, dialog->icon_label,   0, 1, 2, 3);
 	gtk_table_attach_defaults (table, dialog->icon_align,   1, 2, 2, 3);
+#endif
 
 	dialog->orientation_label = NULL;
 	dialog->orientation_combo = NULL;
@@ -839,7 +856,9 @@ panel_properties_dialog_remove_orientation_combo (PanelPropertiesDialog *dialog)
 	g_object_unref (dialog->icon_label);
 	g_object_unref (dialog->icon_align);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	gtk_table_resize (table, 3, 2);
+#endif
 }
 
 static void
@@ -854,7 +873,9 @@ panel_properties_dialog_remove_icon_chooser (PanelPropertiesDialog *dialog)
 	dialog->icon_align = NULL;
 	dialog->icon_chooser = NULL;
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	gtk_table_resize (GTK_TABLE (dialog->general_table), 3, 2);
+#endif
 }
 
 static void
@@ -997,15 +1018,25 @@ panel_properties_dialog_present (PanelToplevel *toplevel)
 	gtk_builder_set_translation_domain (gui, GETTEXT_PACKAGE);
 
 	error = NULL;
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_builder_add_from_file (gui,
+				   BUILDERDIR "/panel-properties-dialog-gtk3.ui",
+				   &error);
+#else
 	gtk_builder_add_from_file (gui,
 				   BUILDERDIR "/panel-properties-dialog.ui",
 				   &error);
+#endif
 
         if (error) {
 		char *secondary;
 
 		secondary = g_strdup_printf (_("Unable to load file '%s': %s."),
+#if GTK_CHECK_VERSION (3, 0, 0)
+					     BUILDERDIR"/panel-properties-dialog-gtk3.ui",
+#else
 					     BUILDERDIR"/panel-properties-dialog.ui",
+#endif
 					     error->message);
 		panel_error_dialog (GTK_WINDOW (toplevel),
 				    gtk_window_get_screen (GTK_WINDOW (toplevel)),
