@@ -27,7 +27,11 @@
 
 #include <gtk/gtk.h>
 
+#include "panel-background.h"
+
+#if GTK_CHECK_VERSION (3, 18, 0)
 #include "panel-enums.h"
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -56,7 +60,9 @@ struct _PanelToplevel {
 	GSettings             *settings;
 	GSettings             *queued_settings;
 	GSettings             *background_settings;
-
+#if GTK_CHECK_VERSION (3, 18, 0)
+	PanelBackground        background;
+#endif
 	PanelToplevelPrivate  *priv;
 };
 
@@ -117,9 +123,6 @@ void                 panel_toplevel_get_position           (PanelToplevel
 							    int                 *y_bottom);
 gboolean             panel_toplevel_get_x_centered         (PanelToplevel       *toplevel);
 gboolean             panel_toplevel_get_y_centered         (PanelToplevel       *toplevel);
-void                 panel_toplevel_set_monitor            (PanelToplevel       *toplevel,
-							    int                  monitor);
-int                  panel_toplevel_get_monitor            (PanelToplevel       *toplevel);
 
 void                 panel_toplevel_rotate                 (PanelToplevel       *toplevel,
 							    gboolean             clockwise);
